import { isBoolean, isString } from '../vendors/toolbox';
import { runExpression, } from '../vendors/organik';
import { BuiltInDataType } from '../types/data-type';
import { getBehaviorByKey } from './theme';
function getDefaultRenderTypeMapOfField() {
    return {
        [BuiltInDataType.Boolean]: getBehaviorByKey('common.field.booleanFieldRenderType'),
        [BuiltInDataType.Integer]: 'number',
        [BuiltInDataType.Float]: 'number',
        [BuiltInDataType.String]: 'input',
        [BuiltInDataType.Text]: 'textarea',
        [BuiltInDataType.Enum]: getBehaviorByKey('common.field.enumFieldRenderType'),
        [BuiltInDataType.MultiEnum]: 'select',
        [BuiltInDataType.Date]: getBehaviorByKey('common.field.dateFieldRenderType'),
        [BuiltInDataType.OneToOne]: 'select',
        [BuiltInDataType.OneToMany]: 'select',
        [BuiltInDataType.ManyToMany]: 'select',
        [BuiltInDataType.ManyToOne]: 'select',
    };
}
function resolveFieldRenderType({ renderType, dataType = '' }) {
    return renderType || getDefaultRenderTypeMapOfField()[dataType] || '';
}
function getDefaultRenderTypeMapOfFilter() {
    return {
        [BuiltInDataType.Boolean]: 'select',
        [BuiltInDataType.String]: 'input',
        [BuiltInDataType.Text]: 'input',
        [BuiltInDataType.Integer]: 'number',
        [BuiltInDataType.Float]: 'number',
        [BuiltInDataType.Enum]: 'select',
        [BuiltInDataType.MultiEnum]: 'select',
        [BuiltInDataType.Date]: getBehaviorByKey('common.filter.dateFilterRenderType'),
        [BuiltInDataType.OneToOne]: 'select',
        [BuiltInDataType.OneToMany]: 'select',
        [BuiltInDataType.ManyToMany]: 'select',
        [BuiltInDataType.ManyToOne]: 'select',
    };
}
function resolveFilterRenderType({ renderType, dataType = '' }) {
    return renderType || getDefaultRenderTypeMapOfFilter()[dataType] || '';
}
function isExprTrue(value, expression, defaultReturnValue) {
    return !!runExpression({ value }, expression, defaultReturnValue);
}
function resolveReadonly(value, readonly) {
    if (isBoolean(readonly)) {
        return readonly;
    }
    return isString(readonly) ? isExprTrue(value, readonly) : false;
}
function resolveFieldRequired(value, readonly, required) {
    if (readonly) {
        return false;
    }
    return isString(required) ? isExprTrue(value, required) : required;
}
export { resolveFieldRenderType, resolveFilterRenderType, isExprTrue, resolveReadonly, resolveFieldRequired, };
